# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.1.2-rc1
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from polyaxon_sdk.models.v1_artifacts_type import V1ArtifactsType
from polyaxon_sdk.models.v1_dockerfile_type import V1DockerfileType
from polyaxon_sdk.models.v1_file_type import V1FileType
from polyaxon_sdk.models.v1_git_type import V1GitType
from polyaxon_sdk.models.v1_tensorboard_type import V1TensorboardType

class V1Init(BaseModel):
    """
    V1Init
    """
    artifacts: Optional[V1ArtifactsType] = None
    paths: Optional[conlist(Dict[str, Any])] = None
    git: Optional[V1GitType] = None
    dockerfile: Optional[V1DockerfileType] = None
    file: Optional[V1FileType] = None
    tensorboard: Optional[V1TensorboardType] = None
    lineage_ref: Optional[StrictStr] = Field(None, alias="lineageRef")
    artifact_ref: Optional[StrictStr] = Field(None, alias="artifactRef")
    model_ref: Optional[StrictStr] = Field(None, alias="modelRef")
    connection: Optional[StrictStr] = None
    path: Optional[StrictStr] = None
    container: Optional[Dict[str, Any]] = None
    __properties = ["artifacts", "paths", "git", "dockerfile", "file", "tensorboard", "lineageRef", "artifactRef", "modelRef", "connection", "path", "container"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Init:
        """Create an instance of V1Init from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of artifacts
        if self.artifacts:
            _dict['artifacts'] = self.artifacts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of git
        if self.git:
            _dict['git'] = self.git.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dockerfile
        if self.dockerfile:
            _dict['dockerfile'] = self.dockerfile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tensorboard
        if self.tensorboard:
            _dict['tensorboard'] = self.tensorboard.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Init:
        """Create an instance of V1Init from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Init.parse_obj(obj)

        _obj = V1Init.parse_obj({
            "artifacts": V1ArtifactsType.from_dict(obj.get("artifacts")) if obj.get("artifacts") is not None else None,
            "paths": obj.get("paths"),
            "git": V1GitType.from_dict(obj.get("git")) if obj.get("git") is not None else None,
            "dockerfile": V1DockerfileType.from_dict(obj.get("dockerfile")) if obj.get("dockerfile") is not None else None,
            "file": V1FileType.from_dict(obj.get("file")) if obj.get("file") is not None else None,
            "tensorboard": V1TensorboardType.from_dict(obj.get("tensorboard")) if obj.get("tensorboard") is not None else None,
            "lineage_ref": obj.get("lineageRef"),
            "artifact_ref": obj.get("artifactRef"),
            "model_ref": obj.get("modelRef"),
            "connection": obj.get("connection"),
            "path": obj.get("path"),
            "container": obj.get("container")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.1.2-rc1
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, conlist
from polyaxon_sdk.models.v1_status_condition import V1StatusCondition
from polyaxon_sdk.models.v1_statuses import V1Statuses

class V1Agent(BaseModel):
    """
    V1Agent
    """
    uuid: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    tags: Optional[conlist(StrictStr)] = None
    live_state: Optional[StrictInt] = None
    namespace: Optional[StrictStr] = None
    version_api: Optional[Dict[str, Any]] = None
    version: Optional[StrictStr] = None
    content: Optional[StrictStr] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    status: Optional[V1Statuses] = None
    status_conditions: Optional[conlist(V1StatusCondition)] = None
    is_replica: Optional[StrictBool] = None
    is_ui_managed: Optional[StrictBool] = None
    settings: Optional[Dict[str, Any]] = None
    __properties = ["uuid", "name", "description", "tags", "live_state", "namespace", "version_api", "version", "content", "created_at", "updated_at", "status", "status_conditions", "is_replica", "is_ui_managed", "settings"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Agent:
        """Create an instance of V1Agent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in status_conditions (list)
        _items = []
        if self.status_conditions:
            for _item in self.status_conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['status_conditions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Agent:
        """Create an instance of V1Agent from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Agent.parse_obj(obj)

        _obj = V1Agent.parse_obj({
            "uuid": obj.get("uuid"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "tags": obj.get("tags"),
            "live_state": obj.get("live_state"),
            "namespace": obj.get("namespace"),
            "version_api": obj.get("version_api"),
            "version": obj.get("version"),
            "content": obj.get("content"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "status": obj.get("status"),
            "status_conditions": [V1StatusCondition.from_dict(_item) for _item in obj.get("status_conditions")] if obj.get("status_conditions") is not None else None,
            "is_replica": obj.get("is_replica"),
            "is_ui_managed": obj.get("is_ui_managed"),
            "settings": obj.get("settings")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.1.2-rc1
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from polyaxon_sdk.models.v1_notification import V1Notification
from polyaxon_sdk.models.v1_polyaxon_sidecar_container import V1PolyaxonSidecarContainer

class V1Plugins(BaseModel):
    """
    V1Plugins
    """
    auth: Optional[StrictBool] = None
    docker: Optional[StrictBool] = None
    shm: Optional[StrictBool] = None
    mount_artifacts_store: Optional[StrictBool] = Field(None, alias="mountArtifactsStore")
    collect_artifacts: Optional[StrictBool] = Field(None, alias="collectArtifacts")
    collect_logs: Optional[StrictBool] = Field(None, alias="collectLogs")
    collect_resources: Optional[StrictBool] = Field(None, alias="collectResources")
    sync_statuses: Optional[StrictBool] = Field(None, alias="syncStatuses")
    auto_resume: Optional[StrictBool] = Field(None, alias="autoResume")
    log_level: Optional[StrictStr] = Field(None, alias="logLevel")
    external_host: Optional[StrictBool] = Field(None, alias="externalHost")
    sidecar: Optional[V1PolyaxonSidecarContainer] = None
    notifications: Optional[conlist(V1Notification)] = None
    __properties = ["auth", "docker", "shm", "mountArtifactsStore", "collectArtifacts", "collectLogs", "collectResources", "syncStatuses", "autoResume", "logLevel", "externalHost", "sidecar", "notifications"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Plugins:
        """Create an instance of V1Plugins from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of sidecar
        if self.sidecar:
            _dict['sidecar'] = self.sidecar.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in notifications (list)
        _items = []
        if self.notifications:
            for _item in self.notifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['notifications'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Plugins:
        """Create an instance of V1Plugins from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Plugins.parse_obj(obj)

        _obj = V1Plugins.parse_obj({
            "auth": obj.get("auth"),
            "docker": obj.get("docker"),
            "shm": obj.get("shm"),
            "mount_artifacts_store": obj.get("mountArtifactsStore"),
            "collect_artifacts": obj.get("collectArtifacts"),
            "collect_logs": obj.get("collectLogs"),
            "collect_resources": obj.get("collectResources"),
            "sync_statuses": obj.get("syncStatuses"),
            "auto_resume": obj.get("autoResume"),
            "log_level": obj.get("logLevel"),
            "external_host": obj.get("externalHost"),
            "sidecar": V1PolyaxonSidecarContainer.from_dict(obj.get("sidecar")) if obj.get("sidecar") is not None else None,
            "notifications": [V1Notification.from_dict(_item) for _item in obj.get("notifications")] if obj.get("notifications") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.1.2-rc1
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1PatchStrategy(str, Enum):
    """
    - replace: Replaces the keys  - isnull: Only set the keys if they do not exist or if they are null  - post_merge: Merge the all keys and replace by new one  - pre_merge: Merge the all keys and keep old ones
    """

    """
    allowed enum values
    """
    REPLACE = 'replace'
    ISNULL = 'isnull'
    POST_MERGE = 'post_merge'
    PRE_MERGE = 'pre_merge'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.1.2-rc1
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, StrictStr, conlist
from polyaxon_sdk.models.v1_run_reference_catalog import V1RunReferenceCatalog
from polyaxon_sdk.models.v1_settings_catalog import V1SettingsCatalog

class V1RunSettings(BaseModel):
    """
    V1RunSettings
    """
    namespace: Optional[StrictStr] = None
    agent: Optional[V1SettingsCatalog] = None
    queue: Optional[V1SettingsCatalog] = None
    artifacts_store: Optional[V1SettingsCatalog] = None
    tensorboard: Optional[Dict[str, Any]] = None
    build: Optional[Dict[str, Any]] = None
    component: Optional[Dict[str, Any]] = None
    models: Optional[conlist(V1RunReferenceCatalog)] = None
    artifacts: Optional[conlist(V1RunReferenceCatalog)] = None
    __properties = ["namespace", "agent", "queue", "artifacts_store", "tensorboard", "build", "component", "models", "artifacts"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1RunSettings:
        """Create an instance of V1RunSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of agent
        if self.agent:
            _dict['agent'] = self.agent.to_dict()
        # override the default output from pydantic by calling `to_dict()` of queue
        if self.queue:
            _dict['queue'] = self.queue.to_dict()
        # override the default output from pydantic by calling `to_dict()` of artifacts_store
        if self.artifacts_store:
            _dict['artifacts_store'] = self.artifacts_store.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in models (list)
        _items = []
        if self.models:
            for _item in self.models:
                if _item:
                    _items.append(_item.to_dict())
            _dict['models'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in artifacts (list)
        _items = []
        if self.artifacts:
            for _item in self.artifacts:
                if _item:
                    _items.append(_item.to_dict())
            _dict['artifacts'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1RunSettings:
        """Create an instance of V1RunSettings from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1RunSettings.parse_obj(obj)

        _obj = V1RunSettings.parse_obj({
            "namespace": obj.get("namespace"),
            "agent": V1SettingsCatalog.from_dict(obj.get("agent")) if obj.get("agent") is not None else None,
            "queue": V1SettingsCatalog.from_dict(obj.get("queue")) if obj.get("queue") is not None else None,
            "artifacts_store": V1SettingsCatalog.from_dict(obj.get("artifacts_store")) if obj.get("artifacts_store") is not None else None,
            "tensorboard": obj.get("tensorboard"),
            "build": obj.get("build"),
            "component": obj.get("component"),
            "models": [V1RunReferenceCatalog.from_dict(_item) for _item in obj.get("models")] if obj.get("models") is not None else None,
            "artifacts": [V1RunReferenceCatalog.from_dict(_item) for _item in obj.get("artifacts")] if obj.get("artifacts") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.1.2-rc1
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictStr, conlist
from polyaxon_sdk.models.v1_build import V1Build
from polyaxon_sdk.models.v1_cache import V1Cache
from polyaxon_sdk.models.v1_component import V1Component
from polyaxon_sdk.models.v1_event_trigger import V1EventTrigger
from polyaxon_sdk.models.v1_hook import V1Hook
from polyaxon_sdk.models.v1_join import V1Join
from polyaxon_sdk.models.v1_param import V1Param
from polyaxon_sdk.models.v1_patch_strategy import V1PatchStrategy
from polyaxon_sdk.models.v1_plugins import V1Plugins
from polyaxon_sdk.models.v1_template import V1Template
from polyaxon_sdk.models.v1_termination import V1Termination
from polyaxon_sdk.models.v1_trigger_policy import V1TriggerPolicy

class V1Operation(BaseModel):
    """
    V1Operation
    """
    version: Optional[StrictFloat] = None
    kind: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    tags: Optional[conlist(StrictStr)] = None
    presets: Optional[conlist(StrictStr)] = None
    queue: Optional[StrictStr] = None
    cache: Optional[V1Cache] = None
    namespace: Optional[StrictStr] = None
    termination: Optional[V1Termination] = None
    plugins: Optional[V1Plugins] = None
    schedule: Optional[Dict[str, Any]] = None
    events: Optional[conlist(V1EventTrigger)] = None
    hooks: Optional[conlist(V1Hook)] = None
    dependencies: Optional[conlist(StrictStr)] = None
    trigger: Optional[V1TriggerPolicy] = None
    conditions: Optional[StrictStr] = None
    skip_on_upstream_skip: Optional[StrictBool] = Field(None, alias="skipOnUpstreamSkip")
    matrix: Optional[Dict[str, Any]] = None
    joins: Optional[Dict[str, V1Join]] = None
    params: Optional[Dict[str, V1Param]] = None
    run_patch: Optional[Dict[str, Any]] = Field(None, alias="runPatch")
    patch_strategy: Optional[V1PatchStrategy] = Field(None, alias="patchStrategy")
    is_preset: Optional[StrictBool] = Field(None, alias="isPreset")
    is_approved: Optional[StrictBool] = Field(None, alias="isApproved")
    template: Optional[V1Template] = None
    build: Optional[V1Build] = None
    cost: Optional[StrictFloat] = None
    path_ref: Optional[StrictStr] = Field(None, alias="pathRef")
    hub_ref: Optional[StrictStr] = Field(None, alias="hubRef")
    dag_ref: Optional[StrictStr] = Field(None, alias="dagRef")
    url_ref: Optional[StrictStr] = Field(None, alias="urlRef")
    component: Optional[V1Component] = None
    __properties = ["version", "kind", "name", "description", "tags", "presets", "queue", "cache", "namespace", "termination", "plugins", "schedule", "events", "hooks", "dependencies", "trigger", "conditions", "skipOnUpstreamSkip", "matrix", "joins", "params", "runPatch", "patchStrategy", "isPreset", "isApproved", "template", "build", "cost", "pathRef", "hubRef", "dagRef", "urlRef", "component"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Operation:
        """Create an instance of V1Operation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of cache
        if self.cache:
            _dict['cache'] = self.cache.to_dict()
        # override the default output from pydantic by calling `to_dict()` of termination
        if self.termination:
            _dict['termination'] = self.termination.to_dict()
        # override the default output from pydantic by calling `to_dict()` of plugins
        if self.plugins:
            _dict['plugins'] = self.plugins.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in events (list)
        _items = []
        if self.events:
            for _item in self.events:
                if _item:
                    _items.append(_item.to_dict())
            _dict['events'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in hooks (list)
        _items = []
        if self.hooks:
            for _item in self.hooks:
                if _item:
                    _items.append(_item.to_dict())
            _dict['hooks'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in joins (dict)
        _field_dict = {}
        if self.joins:
            for _key in self.joins:
                if self.joins[_key]:
                    _field_dict[_key] = self.joins[_key].to_dict()
            _dict['joins'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in params (dict)
        _field_dict = {}
        if self.params:
            for _key in self.params:
                if self.params[_key]:
                    _field_dict[_key] = self.params[_key].to_dict()
            _dict['params'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        # override the default output from pydantic by calling `to_dict()` of build
        if self.build:
            _dict['build'] = self.build.to_dict()
        # override the default output from pydantic by calling `to_dict()` of component
        if self.component:
            _dict['component'] = self.component.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Operation:
        """Create an instance of V1Operation from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Operation.parse_obj(obj)

        _obj = V1Operation.parse_obj({
            "version": obj.get("version"),
            "kind": obj.get("kind"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "tags": obj.get("tags"),
            "presets": obj.get("presets"),
            "queue": obj.get("queue"),
            "cache": V1Cache.from_dict(obj.get("cache")) if obj.get("cache") is not None else None,
            "namespace": obj.get("namespace"),
            "termination": V1Termination.from_dict(obj.get("termination")) if obj.get("termination") is not None else None,
            "plugins": V1Plugins.from_dict(obj.get("plugins")) if obj.get("plugins") is not None else None,
            "schedule": obj.get("schedule"),
            "events": [V1EventTrigger.from_dict(_item) for _item in obj.get("events")] if obj.get("events") is not None else None,
            "hooks": [V1Hook.from_dict(_item) for _item in obj.get("hooks")] if obj.get("hooks") is not None else None,
            "dependencies": obj.get("dependencies"),
            "trigger": obj.get("trigger"),
            "conditions": obj.get("conditions"),
            "skip_on_upstream_skip": obj.get("skipOnUpstreamSkip"),
            "matrix": obj.get("matrix"),
            "joins": dict((_k, V1Join.from_dict(_v)) for _k, _v in obj.get("joins").items()) if obj.get("joins") is not None else None,
            "params": dict((_k, V1Param.from_dict(_v)) for _k, _v in obj.get("params").items()) if obj.get("params") is not None else None,
            "run_patch": obj.get("runPatch"),
            "patch_strategy": obj.get("patchStrategy"),
            "is_preset": obj.get("isPreset"),
            "is_approved": obj.get("isApproved"),
            "template": V1Template.from_dict(obj.get("template")) if obj.get("template") is not None else None,
            "build": V1Build.from_dict(obj.get("build")) if obj.get("build") is not None else None,
            "cost": obj.get("cost"),
            "path_ref": obj.get("pathRef"),
            "hub_ref": obj.get("hubRef"),
            "dag_ref": obj.get("dagRef"),
            "url_ref": obj.get("urlRef"),
            "component": V1Component.from_dict(obj.get("component")) if obj.get("component") is not None else None
        })
        return _obj

